Index: src/full-codegen/ppc/full-codegen-ppc.cc |
diff --git a/src/full-codegen/ppc/full-codegen-ppc.cc b/src/full-codegen/ppc/full-codegen-ppc.cc |
index 5bc7e24017445e1ffb9cc995e4256997e5597fa6..29bc5fc2460acc048f70a25cd3ee981a66021d9c 100644 |
--- a/src/full-codegen/ppc/full-codegen-ppc.cc |
+++ b/src/full-codegen/ppc/full-codegen-ppc.cc |
@@ -4,15 +4,16 @@ |
#if V8_TARGET_ARCH_PPC |
-#include "src/full-codegen/full-codegen.h" |
#include "src/ast/compile-time-value.h" |
#include "src/ast/scopes.h" |
+#include "src/builtins/builtins-constructor.h" |
#include "src/code-factory.h" |
#include "src/code-stubs.h" |
#include "src/codegen.h" |
#include "src/compilation-info.h" |
#include "src/compiler.h" |
#include "src/debug/debug.h" |
+#include "src/full-codegen/full-codegen.h" |
#include "src/ic/ic.h" |
#include "src/ppc/code-stubs-ppc.h" |
@@ -206,12 +207,14 @@ void FullCodeGenerator::Generate() { |
if (info->scope()->new_target_var() != nullptr) { |
__ push(r6); // Preserve new target. |
} |
- if (slots <= FastNewFunctionContextStub::MaximumSlots()) { |
- FastNewFunctionContextStub stub(isolate(), info->scope()->scope_type()); |
+ if (slots <= |
+ ConstructorBuiltinsAssembler::MaximumFunctionContextSlots()) { |
+ Callable callable = CodeFactory::FastNewFunctionContext( |
+ isolate(), info->scope()->scope_type()); |
__ mov(FastNewFunctionContextDescriptor::SlotsRegister(), |
Operand(slots)); |
- __ CallStub(&stub); |
- // Result of FastNewFunctionContextStub is always in new space. |
+ __ Call(callable.code(), RelocInfo::CODE_TARGET); |
+ // Result of the FastNewFunctionContext builtin is always in new space. |
need_write_barrier = false; |
} else { |
__ push(r4); |
@@ -1186,8 +1189,9 @@ void FullCodeGenerator::VisitObjectLiteral(ObjectLiteral* expr) { |
__ Push(r6, r5, r4, r3); |
__ CallRuntime(Runtime::kCreateObjectLiteral); |
} else { |
- FastCloneShallowObjectStub stub(isolate(), expr->properties_count()); |
- __ CallStub(&stub); |
+ Callable callable = CodeFactory::FastCloneShallowObject( |
+ isolate(), expr->properties_count()); |
+ __ Call(callable.code(), RelocInfo::CODE_TARGET); |
RestoreContext(); |
} |
PrepareForBailoutForId(expr->CreateLiteralId(), BailoutState::TOS_REGISTER); |
@@ -1322,8 +1326,9 @@ void FullCodeGenerator::VisitArrayLiteral(ArrayLiteral* expr) { |
__ Push(r6, r5, r4, r3); |
__ CallRuntime(Runtime::kCreateArrayLiteral); |
} else { |
- FastCloneShallowArrayStub stub(isolate(), allocation_site_mode); |
- __ CallStub(&stub); |
+ Callable callable = |
+ CodeFactory::FastCloneShallowArray(isolate(), allocation_site_mode); |
+ __ Call(callable.code(), RelocInfo::CODE_TARGET); |
RestoreContext(); |
} |
PrepareForBailoutForId(expr->CreateLiteralId(), BailoutState::TOS_REGISTER); |